'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.makeSCDriver = makeSCDriver;

var _xstream = require('xstream');

var _xstream2 = _interopRequireDefault(_xstream);

var _socketclusterClient = require('socketcluster-client');

var _socketclusterClient2 = _interopRequireDefault(_socketclusterClient);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 *
 * @param options {
  hostname: 'securedomain.com',
  secure: true,
  port: 443,
  rejectUnauthorized: false // Only necessary during debug if using a self-signed certificate
}
 * @returns {scDriver}
 */
function makeSCDriver(options) {
    var socket = _socketclusterClient2.default.connect(options);
    function get(eventName) {
        var _ref = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

        var _ref$multiArgs = _ref.multiArgs;
        var multiArgs = _ref$multiArgs === undefined ? false : _ref$multiArgs;


        return _xstream2.default.create({
            start: function start(listener) {
                this.eventListener = multiArgs ? function () {
                    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
                        args[_key] = arguments[_key];
                    }

                    return listener.next(args);
                } : function (arg) {
                    return listener.next(arg);
                };

                socket.on(eventName, this.eventListener);
            },
            stop: function stop() {
                socket.off(eventName, this.eventListener);
            },

            eventListener: null
        });
    }

    function publish(messageType, message) {
        socket.emit(messageType, message);
    }

    return function scDriver(events$) {
        if (events$) {
            events$.addListener({
                next: function next(i) {
                    publish(i.messageType, i.message);
                },
                error: function error(err) {
                    return console.error(err);
                },
                complete: function complete() {
                    socket.disconnect();
                }
            });
        }
        return {
            get: get,
            socket: socket,
            dispose: function dispose() {}
        };
    };
}